@@ -81,7 +81,7 @@ def store(request, project_id=None):
     if 'HTTP_ORIGIN' in request.META:
         origin = request.META.get('HTTP_ORIGIN', '')
         if not is_valid_origin(origin, project):
-            raise APIError('Invalid origin')
+            return HttpResponse('Invalid origin', status_code=400)
     else:
         origin = None
 
@@ -139,15 +139,15 @@ def store(request, project_id=None):
 
             insert_data_to_database(data)
         except APIError, error:
-            logger.error('Client %r raised API error: %s' % (client, error), exc_info=True)
+            logger.error('Client %r raised API error: %s' % (client, error))
             response = HttpResponse(unicode(error.msg), status=error.http_status)
         else:
             if request.method == 'POST':
                 logger.info('New event from client %r (id=%%s)' % client, data['event_id'])
             response = HttpResponse('')
-    else:
-        # OPTIONS
-        response = apply_access_control_headers(HttpResponse(), origin)
+
+    response = apply_access_control_headers(HttpResponse(), origin)
+
     return response
 
 
